@@ -1,48 +1,36 @@
 multinomialCode <-
 function(data, alternative, npNumbers, np.interval, beta, method){
-  
-  #Function to calculate the test statistic for a given table:
-  testStatistic <- function(method, i, j, k, alternative){
-    
-    if(method=="z-pooled"){
-      TX <- (i/(i+k)-j/(j+(N-i-j-k)))/sqrt((i+j)/N*(1-(i+j)/N)*(1/(i+k)+1/(j+(N-i-j-k))))
-    }
-    
-    if(method=="boschloo"){
-      TX <- {}
-      for(l in k){
-        TX <- c(TX, fisher.2x2(matrix(c(i,j,l,N-i-j-l),nrow=2), alternative=alternative))
-      }
-    }
-    
-    if(method=="z-unpooled"){
-      TX <- (i/(i+k)-j/(N-i-k))/sqrt(j/(N-i-k)*(1-j/(N-i-k))/(N-i-k)+i/(i+k)*(1-i/(i+k))/(i+k))
-    }
-    
-    TX[is.na(TX)] <- 0
-    TX <- signif(TX, 12) #Remove rounding errors
-    return(TX)
-  }
-  
+ 
   N <- sum(data)
   
   #Observed test statistic:
-  TXO <- testStatistic(method=method, data[1,1], data[1,2], data[2,1], alternative=alternative)
+  TXO <- switch(method, 
+                "z-pooled" = zpooled_TX(data, Ns=.colSums(data, 2, 2), delta=0),
+                "z-unpooled" = zunpooled_TX(data, Ns=.colSums(data, 2, 2), delta=0),
+                "boschloo" = fisher.2x2(data, alternative=alternative))[3]
   
   #The p-value calculation function for Multinomial model:
   #Since function is symmetric, do not need to consider all values.
-  MultiProb <- function(p1,p2){
+  MultiProb <- function(p1, p2){
     prob <- 0
-    for(i in 0:N){
-      for(j in 0:(N-i)){
-        TXcrit <- testStatistic(method=method, i, j, 0:(N-i-j), alternative=alternative)
+    for (i in 0:N){
+      for (j in 0:(N-i)){
         
-        if(alternative=="less" || method=="boschloo"){k <- which(!is.na(TXcrit)&TXcrit <= TXO)-1
-        } else if(alternative=="greater"){k <- which(!is.na(TXcrit)&TXcrit >= TXO)-1
-        } else if(alternative=="two.sided"){k <- which(!is.na(TXcrit)&abs(TXcrit) >= abs(TXO))-1}
+        Tbls <- expand.grid(i, j, 0:(N-i-j))
+        TXcrit <- apply(Tbls, 1, function(x) {
+          dataTemp <- matrix(c(x, N-sum(x)), ncol=2, byrow=TRUE)
+          switch(method, 
+                 "z-pooled" = zpooled_TX(dataTemp, Ns=.colSums(dataTemp, 2, 2), delta=0),
+                 "z-unpooled" = zunpooled_TX(dataTemp, Ns=.colSums(dataTemp, 2, 2), delta=0),
+                 "boschloo" = fisher.2x2(dataTemp, alternative=alternative))[3]
+        })
+        
+        if (alternative=="less" || method=="boschloo") { k <- which(!is.na(TXcrit)&TXcrit <= TXO)-1
+        } else if (alternative=="greater") { k <- which(!is.na(TXcrit)&TXcrit >= TXO)-1
+        } else if (alternative=="two.sided") { k <- which(!is.na(TXcrit)&abs(TXcrit) >= abs(TXO))-1}
         
         #Calculate probability even for vector of p2
-        if(length(k) > 0){
+        if (length(k) > 0) {
           prob <- prob + colSums(exp(lgamma(N+1)-lgamma(i+1)-lgamma(j+1)-lgamma(k+1)-lgamma(N-i-j-k+1))*p1^(i+j)*
                                    matrix(rep(p2,each=length(k))^(i+rep(k,length(p2))),length(k),length(p2))*(1-p1)^(N-i-j)*
                                    matrix((1-rep(p2,each=length(k)))^(N-i-rep(k,length(p2))),length(k),length(p2)))
@@ -66,19 +54,21 @@ function(data, alternative, npNumbers, np.interval, beta, method){
   
   #Search for the maximum p-value (2 nuisance parameters):
   maxProb <- np1 <- np2 <- 0
-  for(np1s in int1){
-    if (np1s > max(int2)){int2temp <- int2
-    } else if(min(int2) < min(int1)){int2temp <- c(seq(min(int2),min(int1),length=npNumbers),seq(np1s,max(int2), length=npNumbers))
-    } else {int2temp <- seq(np1s,max(int2), length=npNumbers)}
+  for (np1s in int1) {
+    if (np1s > max(int2)) {int2temp <- int2
+    } else if (min(int2) < min(int1)) {int2temp <- c(seq(min(int2), min(int1),length=npNumbers), seq(np1s, max(int2), length=npNumbers))
+    } else { int2temp <- seq(np1s, max(int2), length=npNumbers) }
     
     prob <- t(MultiProb(np1s, int2temp))
-    if(max(prob) > maxProb){
+    if (max(prob) > maxProb) {
       maxProb <- max(prob)
       pvalue <- maxProb + beta
       np1 <- np1s
       np2 <- int2temp[max.col(prob)]
     }
   }
+  #Note: if beta is large, can have a p-value greater than 1.  Cap at 1
+  pvalue[pvalue > 1] <- 1
   
   return(list(method=method, p.value=max(pvalue), test.statistic=TXO, np1=np1, np2=np2,
               np1.range=c(min(int1),max(int1)), np2.range=c(min(int2), max(int2))))
